package geniusweb.exampleparties.timedependentparty;

import static org.junit.Assert.assertEquals;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.fasterxml.jackson.databind.ObjectMapper;

import geniusweb.profile.Profile;
import geniusweb.profile.utilityspace.UtilitySpace;

@RunWith(Parameterized.class)
public class ExtendedUtilSpaceTest {
	private final static ObjectMapper jackson = new ObjectMapper();
	private final static double SMALL = 0.0001;

	@Parameters
	public static Collection<Object[]> data() {
		return Arrays.asList(new Object[][] {
				{ "src/test/resources/jobs/jobs1.json", 0.02 },
				{ "src/test/resources/7issues/7issues1.json", 0.0055 },
				{ "src/test/resources/9issues/9issues1.json", 0.0013 },
				// tolerance in computerbuy is quite small because approximation
				// scales the space
				{ "src/test/resources/computer/computerbuy.json", 0.0016 } });
	}

	private String filename;
	private double expectedTolerance;
	private ExtendedUtilSpace space;

	public ExtendedUtilSpaceTest(String filename, double expectedTolerance) {
		this.filename = filename;
		this.expectedTolerance = expectedTolerance;
	}

	@Before
	public void before() throws IOException {
		String file = new String(Files.readAllBytes(Paths.get(filename)));
		UtilitySpace profile = (UtilitySpace) jackson.readValue(file,
				Profile.class);
		space = new ExtendedUtilSpace(profile);
	}

	@Test
	public void smokeTest() {

	}

	@Test
	public void testTolerance() {
		assertEquals(expectedTolerance, space.computeTolerance().doubleValue(),
				SMALL);
	}
}
